@@ -1,10 +1,10 @@
 package Net::DNS::Header;
 
 #
-# $Id: Header.pm 1348 2015-05-27 09:55:13Z willem $
+# $Id: Header.pm 1356 2015-06-11 08:44:12Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1348 $)[1];
+$VERSION = (qw$LastChangedRevision: 1356 $)[1];
 
 
 =head1 NAME
@@ -169,9 +169,9 @@ sub rcode {
 			return $rcode == 16 ? 'BADVERS' : rcodebyval($rcode);
 		}
 		my $rcode = rcodebyname($arg);
-		$opt->rcode($rcode);				# write back full 12-bit rcode
-		$_ &= 0xfff0;					# write back low 4-bit rcode
-		$_ |= ( $rcode & 0x000f ) if $rcode < 16 or $opt->rcode;
+		$opt->rcode($rcode);				# full 12-bit rcode
+		$_ &= 0xfff0;					# low 4-bit rcode
+		$_ |= ( $rcode & 0x000f );
 		return $rcode;
 	}
 }
@@ -431,17 +431,6 @@ sub edns {
 
 ########################################
 
-use vars qw($AUTOLOAD);
-
-sub AUTOLOAD {			## Default method
-	no strict;
-	@_ = ("method $AUTOLOAD undefined");
-	goto &{'Carp::confess'};
-}
-
-sub DESTROY { }			## Avoid tickling AUTOLOAD (in cleanup)
-
-
 sub _dnsflag {
 	my $self = shift;
 	my $flag = shift;
