@@ -1,10 +1,10 @@
 package Net::DNS::Packet;
 
 #
-# $Id: Packet.pm 1348 2015-05-27 09:55:13Z willem $
+# $Id: Packet.pm 1358 2015-06-11 09:32:52Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1348 $)[1];
+$VERSION = (qw$LastChangedRevision: 1358 $)[1];
 
 
 =head1 NAME
@@ -114,7 +114,6 @@ sub decode {
 	my $offset = 0;
 	my $self;
 	eval {
-		local $SIG{__WARN__} = sub { die @_ };
 		die 'corrupt wire-format data' if length($$data) < HEADER_LENGTH;
 
 		# header section
@@ -160,9 +159,10 @@ sub decode {
 		return $self;
 	};
 
-	if ( $debug && $self ) {
-		local $@;
-		$self->print;
+	if ($debug) {
+		local $@ = $@;
+		print $@ if $@;
+		$self->print if $self;
 	}
 
 	return wantarray ? ( $self, $offset ) : $self;
@@ -271,7 +271,7 @@ sub reply {
 	my @question = $query->question;
 	$reply->{question} = [@question];
 
-	$header->rcode('FORMERR');				# failure to provide RCODE is sinful!
+	$header->rcode('FORMERR');				# no RCODE considered sinful!
 
 	$header->rd( $qheadr->rd );				# copy these flags into reply
 	$header->cd( $qheadr->cd );
@@ -381,7 +381,8 @@ sub string {
 	my $update = $header->opcode eq 'UPDATE';
 
 	my $server = $self->{answerfrom};
-	my $string = $server ? ";; Answer received from $server ($self->{answersize} bytes)\n" : "";
+	my $length = $self->{answersize};
+	my $string = $server ? ";; Answer received from $server ($length bytes)\n" : "";
 
 	$string .= ";; HEADER SECTION\n" . $header->string;
 
@@ -424,8 +425,7 @@ User-created packets will return undef for this method.
 sub answerfrom {
 	my $self = shift;
 
-	return $self->{answerfrom} = shift if scalar @_;
-
+	$self->{answerfrom} = shift if scalar @_;
 	return $self->{answerfrom};
 }
 
@@ -621,7 +621,7 @@ sub sign_tsig {
 		my $tsig = Net::DNS::RR::TSIG->create(@_);
 		$self->push( 'additional' => $tsig );
 		return $tsig;
-	} || croak "$@TSIG: unable to sign packet";
+	} || croak "$@\nTSIG: unable to sign packet";
 }
 
 
@@ -698,7 +698,7 @@ sub sign_sig0 {
 			$sig0 = Net::DNS::RR::SIG->create( '', $karg );
 
 		} else {
-			die "unexpected $kref argument passed to sign_sig0";
+			croak "sign_sig0: unexpected $kref argument";
 		}
 
 		$self->push( 'additional' => $sig0 );
@@ -707,6 +707,19 @@ sub sign_sig0 {
 }
 
 
+sub sigrr {				## obtain packet signature RR
+	my $self = shift;
+
+	my ($sig) = reverse $self->additional;
+	return undef unless $sig;
+	return $sig if $sig->type eq 'TSIG';
+	return $sig if $sig->type eq 'SIG';
+	return undef;
+}
+
+
+########################################
+
 =head2 truncate
 
 The truncate method takes a maximum length as argument and then tries
@@ -797,28 +810,6 @@ sub dump {				## print internal data structure
 }
 
 
-sub sigrr {				## obtain packet signature RR
-	my $self = shift;
-
-	my ($sig) = reverse $self->additional;
-	return undef unless $sig;
-	return $sig if $sig->type eq 'TSIG';
-	return $sig if $sig->type eq 'SIG';
-	return undef;
-}
-
-
-sub DESTROY { }				## Avoid tickling AUTOLOAD (in cleanup)
-
-use vars qw($AUTOLOAD);
-
-sub AUTOLOAD {				## Default method
-	no strict;
-	@_ = ("method $AUTOLOAD undefined");
-	goto &{'Carp::confess'};
-}
-
-
 1;
 __END__
 
