@@ -1,16 +1,16 @@
 package Net::DNS::Parameters;
 
 #
-# $Id: Parameters.pm 1341 2015-05-10 15:31:26Z willem $
+# $Id: Parameters.pm 1358 2015-06-11 09:32:52Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1341 $)[1];
+$VERSION = (qw$LastChangedRevision: 1358 $)[1];
 
 
 ################################################
 ##
 ##	Domain Name System (DNS) Parameters
-##	(last updated 2015-03-26)
+##	(last updated 2015-06-04)
 ##
 ################################################
 
@@ -124,7 +124,7 @@ use vars qw( %typebyname %typebyval );
 	MAILB	   => 253,					# RFC1035
 	MAILA	   => 254,					# RFC1035
 	ANY	   => 255,					# RFC1035 RFC6895
-	URI	   => 256,					# RFC-faltstrom-uri-14
+	URI	   => 256,					# RFC7553
 	CAA	   => 257,					# RFC6844
 	TA	   => 32768,					# http://cameo.library.cmu.edu/ http://www.watson.org/~weiler/INI1999-19.pdf
 	DLV	   => 32769,					# RFC4431
@@ -217,7 +217,7 @@ sub classbyname {
 	my $name = shift;
 
 	$classbyname{$name} || do {
-		croak "unknown type $name" unless $name =~ m/CLASS(\d+)/i;
+		croak "unknown class $name" unless $name =~ m/CLASS(\d+)/i;
 		my $val = 0 + $1;
 		croak "classbyname( $name ) out of range" if $val > 0xffff;
 		return $val;
@@ -349,7 +349,7 @@ DEALINGS IN THE SOFTWARE.
 =head1 SEE ALSO
 
 L<perl>, L<Net::DNS>,
-L<IANA Registry|http://www.iana.org/assignments/dns-parameters/>
+L<IANA Registry|http://www.iana.org/assignments/dns-parameters>
 
 =cut
 
