@@ -1,12 +1,14 @@
 package Net::DNS::RR::A;
 
 #
-# $Id: A.pm 1068 2012-12-06 10:38:51Z willem $
+# $Id: A.pm 1348 2015-05-27 09:55:13Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1068 $)[1];
+$VERSION = (qw$LastChangedRevision: 1348 $)[1];
 
-use base Net::DNS::RR;
+
+use strict;
+use base qw(Net::DNS::RR);
 
 =head1 NAME
 
@@ -15,7 +17,6 @@ Net::DNS::RR::A - DNS A resource record
 =cut
 
 
-use strict;
 use integer;
 
 
@@ -50,17 +51,21 @@ sub parse_rdata {			## populate RR from rdata in argument list
 }
 
 
+my $pad = pack 'x4';
+
 sub address {
 	my $self = shift;
 
-	return join '.', unpack( 'C4', $self->{address} ) unless @_;
+	return join '.', unpack 'C4', $self->{address} . $pad unless scalar @_;
 
 	# Note: pack masks overlarge values, mostly without warning
 	my @part = split /\./, shift || '';
 	my $last = pop(@part) || 0;
+	$self = {} unless ref($self);
 	$self->{address} = pack 'C4', @part, (0) x ( 3 - @part ), $last;
 }
 
+
 1;
 __END__
 
@@ -100,14 +105,30 @@ Version 4 IP address represented using dotted-quad notation.
 
 =head1 COPYRIGHT
 
-Copyright (c)1997-1998 Michael Fuhr. 
-
-Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
+Copyright (c)1997 Michael Fuhr. 
 
 All rights reserved.
 
-This program is free software; you may redistribute it and/or
-modify it under the same terms as Perl itself.
+Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
+
+
+=head1 LICENSE
+
+Permission to use, copy, modify, and distribute this software and its
+documentation for any purpose and without fee is hereby granted, provided
+that the above copyright notice appear in all copies and that both that
+copyright notice and this permission notice appear in supporting
+documentation, and that the name of the author not be used in advertising
+or publicity pertaining to distribution of the software without specific
+prior written permission.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+DEALINGS IN THE SOFTWARE.
 
 
 =head1 SEE ALSO
