@@ -1,12 +1,14 @@
 package Net::DNS::RR::CERT;
 
 #
-# $Id: CERT.pm 1101 2013-08-14 14:40:00Z willem $
+# $Id: CERT.pm 1347 2015-05-19 10:24:36Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1101 $)[1];
+$VERSION = (qw$LastChangedRevision: 1347 $)[1];
 
-use base Net::DNS::RR;
+
+use strict;
+use base qw(Net::DNS::RR);
 
 =head1 NAME
 
@@ -71,13 +73,10 @@ sub encode_rdata {			## encode rdata as wire-format octet string
 sub format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless $self->{certbin};
-	my $format    = $r_formats{$self->{format}}	  || $self->{format};
+	my @base64 = split /\s+/, encode_base64( $self->{certbin} || return '' );
 	my $algorithm = $r_algorithms{$self->{algorithm}} || $self->{algorithm};
-	my $base64    = MIME::Base64::encode $self->{certbin};
-	chomp $base64;
-	return "$format $self->{tag} $algorithm $base64" if length($base64) < 40;
-	return "$format $self->{tag} $algorithm (\n$base64 )";
+	my $format    = $r_formats{$self->{format}}	  || $self->{format};
+	my @rdata = $format, $self->{tag}, $algorithm, @base64;
 }
 
 
@@ -101,6 +100,7 @@ sub format {
 	$self->{format} = $format;
 }
 
+
 sub tag {
 	my $self = shift;
 
@@ -108,6 +108,7 @@ sub tag {
 	return $self->{tag} || 0;
 }
 
+
 sub algorithm {
 	my $self = shift;
 
@@ -120,13 +121,15 @@ sub algorithm {
 	$self->{algorithm} = $algorithm;
 }
 
+
 sub cert {
 	my $self = shift;
 
-	$self->{certbin} = MIME::Base64::decode( join "", @_ ) if scalar @_;
-	return MIME::Base64::encode( $self->certbin, "" ) if defined wantarray;
+	$self->certbin( MIME::Base64::decode( join "", @_ ) ) if scalar @_;
+	return MIME::Base64::encode( $self->certbin(), "" ) if defined wantarray;
 }
 
+
 sub certbin {
 	my $self = shift;
 
@@ -134,7 +137,9 @@ sub certbin {
 	$self->{certbin} || "";
 }
 
-sub certificate { &certbin; }			## historical
+
+sub certificate { &certbin; }		## historical
+
 
 1;
 __END__
@@ -168,6 +173,7 @@ Returns the format code for the certificate (in numeric form)
 =head2 tag
 
     $tag = $rr->tag;
+    $rr->tag( $tag );
 
 Returns the key tag for the public key in the certificate
 
@@ -180,12 +186,14 @@ Returns the algorithm used by the certificate (in numeric form).
 =head2 cert
 
     $cert = $rr->cert;
+    $rr->cert( $cert );
 
 Base64 representation of the certificate.
 
 =head2 certbin
 
     $certbin = $rr->certbin;
+    $rr->certbin( $certbin );
 
 Binary representation of the certificate.
 
@@ -194,12 +202,28 @@ Binary representation of the certificate.
 
 Copyright (c)2002 VeriSign, Mike Schiraldi
 
-Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
-
 All rights reserved.
 
-This program is free software; you may redistribute it and/or
-modify it under the same terms as Perl itself.
+Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
+
+
+=head1 LICENSE
+
+Permission to use, copy, modify, and distribute this software and its
+documentation for any purpose and without fee is hereby granted, provided
+that the above copyright notice appear in all copies and that both that
+copyright notice and this permission notice appear in supporting
+documentation, and that the name of the author not be used in advertising
+or publicity pertaining to distribution of the software without specific
+prior written permission.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+DEALINGS IN THE SOFTWARE.
 
 
 =head1 SEE ALSO
