@@ -1,12 +1,14 @@
 package Net::DNS::RR::DHCID;
 
 #
-# $Id: DHCID.pm 1037 2012-10-24 21:50:15Z willem $
+# $Id: DHCID.pm 1339 2015-04-16 13:01:17Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1037 $)[1];
+$VERSION = (qw$LastChangedRevision: 1339 $)[1];
 
-use base Net::DNS::RR;
+
+use strict;
+use base qw(Net::DNS::RR);
 
 =head1 NAME
 
@@ -15,7 +17,6 @@ Net::DNS::RR::DHCID - DNS DHCID resource record
 =cut
 
 
-use strict;
 use integer;
 
 use MIME::Base64;
@@ -41,9 +42,7 @@ sub encode_rdata {			## encode rdata as wire-format octet string
 sub format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	my $base64 = MIME::Base64::encode $self->encode_rdata;
-	chomp $base64;
-	return length($base64) > 40 ? "(\n$base64 )" : $base64;
+	my @base64 = split /\s+/, encode_base64( $self->encode_rdata );
 }
 
 
@@ -72,38 +71,43 @@ sub parse_rdata {			## populate RR from rdata in argument list
 #   |      0xffff      | Undefined; RESERVED.                           |
 #   +------------------+------------------------------------------------+
 
+
 sub identifiertype {
 	my $self = shift;
 
-	$self->{identifiertype} = shift if @_;
-	return 0 + ( $self->{identifiertype} || 0 );
+	$self->{identifiertype} = 0 + shift if scalar @_;
+	return $self->{identifiertype} || 0;
 }
 
+
 sub digesttype {
 	my $self = shift;
 
-	$self->{digesttype} = shift if @_;
-	return 0 + ( $self->{digesttype} || 0 );
+	$self->{digesttype} = 0 + shift if scalar @_;
+	return $self->{digesttype} || 0;
 }
 
+
 sub digest {
 	my $self = shift;
 
-	$self->{digest} = shift if @_;
+	$self->{digest} = shift if scalar @_;
 	$self->{digest} || "";
 }
 
+
 sub rdata {
 	my $self = shift;
 
-	if (@_) {
-		my $data = MIME::Base64::decode( join "", @_ ) if @_;
+	if ( scalar @_ ) {
+		my $data = MIME::Base64::decode( join "", @_ );
 		my $size = length($data) - 3;
 		@{$self}{qw(identifiertype digesttype digest)} = unpack "n C a$size", $data;
 	}
 	return MIME::Base64::encode( $self->encode_rdata, "" ) if defined wantarray;
 }
 
+
 1;
 __END__
 
@@ -130,6 +134,7 @@ other unpredictable behaviour.
 =head2 identifiertype
 
     $identifiertype = $rr->identifiertype;
+    $rr->identifiertype( $identifiertype );
 
 The 16-bit identifier type describes the form of host identifier
 used to construct the DHCP identity information.
@@ -137,6 +142,7 @@ used to construct the DHCP identity information.
 =head2 digesttype
 
     $digesttype = $rr->digesttype;
+    $rr->digesttype( $digesttype );
 
 The 8-bit digest type number describes the message-digest
 algorithm used to obfuscate the DHCP identity information.
@@ -144,6 +150,7 @@ algorithm used to obfuscate the DHCP identity information.
 =head2 digest
 
     $digest = $rr->digest;
+    $rr->digest( $digest );
 
 Binary representation of the digest of DHCP identity information.
 
@@ -161,12 +168,28 @@ and will be silently ignored.
 
 Copyright (c)2009 Olaf Kolkman, NLnet Labs.
 
-Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
-
 All rights reserved.
 
-This program is free software; you may redistribute it and/or
-modify it under the same terms as Perl itself.
+Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
+
+
+=head1 LICENSE
+
+Permission to use, copy, modify, and distribute this software and its
+documentation for any purpose and without fee is hereby granted, provided
+that the above copyright notice appear in all copies and that both that
+copyright notice and this permission notice appear in supporting
+documentation, and that the name of the author not be used in advertising
+or publicity pertaining to distribution of the software without specific
+prior written permission.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+DEALINGS IN THE SOFTWARE.
 
 
 =head1 SEE ALSO
