@@ -1,12 +1,14 @@
 package Net::DNS::RR::HINFO;
 
 #
-# $Id: HINFO.pm 1068 2012-12-06 10:38:51Z willem $
+# $Id: HINFO.pm 1348 2015-05-27 09:55:13Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1068 $)[1];
+$VERSION = (qw$LastChangedRevision: 1348 $)[1];
 
-use base Net::DNS::RR;
+
+use strict;
+use base qw(Net::DNS::RR);
 
 =head1 NAME
 
@@ -15,7 +17,6 @@ Net::DNS::RR::HINFO - DNS HINFO resource record
 =cut
 
 
-use strict;
 use integer;
 
 use Net::DNS::Text;
@@ -51,24 +52,26 @@ sub parse_rdata {			## populate RR from rdata in argument list
 
 	$self->cpu(shift);
 	$self->os(shift);
-	die 'too many arguments for HINFO' if @_;
+	die 'too many arguments for HINFO' if scalar @_;
 }
 
 
 sub cpu {
 	my $self = shift;
 
-	$self->{cpu} = new Net::DNS::Text(shift) if @_;
-	$self->{cpu}->value if defined wantarray;
+	$self->{cpu} = new Net::DNS::Text(shift) if scalar @_;
+	$self->{cpu}->value if defined wantarray && $self->{cpu};
 }
 
+
 sub os {
 	my $self = shift;
 
-	$self->{os} = new Net::DNS::Text(shift) if @_;
-	$self->{os}->value if defined wantarray;
+	$self->{os} = new Net::DNS::Text(shift) if scalar @_;
+	$self->{os}->value if defined wantarray && $self->{os};
 }
 
+
 1;
 __END__
 
@@ -95,26 +98,44 @@ other unpredictable behaviour.
 =head2 cpu
 
     $cpu = $rr->cpu;
+    $rr->cpu( $cpu );
 
 Returns the CPU type for this RR.
 
 =head2 os
 
     $os = $rr->os;
+    $rr->os( $os );
 
 Returns the operating system type for this RR.
 
 
 =head1 COPYRIGHT
 
-Copyright (c)1997-1998 Michael Fuhr. 
-
-Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
+Copyright (c)1997 Michael Fuhr. 
 
 All rights reserved.
 
-This program is free software; you may redistribute it and/or
-modify it under the same terms as Perl itself.
+Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
+
+
+=head1 LICENSE
+
+Permission to use, copy, modify, and distribute this software and its
+documentation for any purpose and without fee is hereby granted, provided
+that the above copyright notice appear in all copies and that both that
+copyright notice and this permission notice appear in supporting
+documentation, and that the name of the author not be used in advertising
+or publicity pertaining to distribution of the software without specific
+prior written permission.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+DEALINGS IN THE SOFTWARE.
 
 
 =head1 SEE ALSO
