@@ -1,10 +1,10 @@
 package Net::DNS::RR::HIP;
 
 #
-# $Id: HIP.pm 1188 2014-04-03 18:54:34Z willem $
+# $Id: HIP.pm 1339 2015-04-16 13:01:17Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1188 $)[1];
+$VERSION = (qw$LastChangedRevision: 1339 $)[1];
 
 
 use strict;
@@ -58,11 +58,9 @@ sub format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	return '' unless $self->{hitbin};
-	my $algorithm = $self->pkalgorithm;
-	my $hit	      = $self->hit;
-	my $base64    = MIME::Base64::encode $self->keybin, '';
-	my @servers   = map $_->string, @{$self->{servers}};
-	return "$algorithm $hit (\n$base64\n@servers )";
+	my $base64 = encode_base64( $self->keybin, '' );
+	my @server = map $_->string, @{$self->{servers}};
+	my @rdata = $self->pkalgorithm, $self->hit, $base64, @server;
 }
 
 
@@ -122,13 +120,14 @@ sub servers {
 	return map $_->name, @$servers if defined wantarray;
 }
 
-sub pubkey { &key; }						# historical
+sub pubkey { &key; }			## historical
 
-sub rendezvousservers {						# historical
+sub rendezvousservers {			## historical
 	my @servers = &servers;
 	\@servers;
 }
 
+
 1;
 __END__
 
@@ -202,12 +201,28 @@ Copyright (c)2009 Olaf Kolkman, NLnet Labs
 
 All rights reserved.
 
-This program is free software; you may redistribute it and/or
-modify it under the same terms as Perl itself.
-
 Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 
+=head1 LICENSE
+
+Permission to use, copy, modify, and distribute this software and its
+documentation for any purpose and without fee is hereby granted, provided
+that the above copyright notice appear in all copies and that both that
+copyright notice and this permission notice appear in supporting
+documentation, and that the name of the author not be used in advertising
+or publicity pertaining to distribution of the software without specific
+prior written permission.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+DEALINGS IN THE SOFTWARE.
+
+
 =head1 SEE ALSO
 
 L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC5205
