@@ -1,10 +1,10 @@
 package Net::DNS::RR::ISDN;
 
 #
-# $Id: ISDN.pm 1188 2014-04-03 18:54:34Z willem $
+# $Id: ISDN.pm 1348 2015-05-27 09:55:13Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1188 $)[1];
+$VERSION = (qw$LastChangedRevision: 1348 $)[1];
 
 
 use strict;
@@ -19,32 +19,31 @@ Net::DNS::RR::ISDN - DNS ISDN resource record
 
 use integer;
 
+use Net::DNS::Text;
+
 
 sub decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
 	my ( $data, $offset ) = @_;
 
-	my $asize = unpack "\@$offset C", $$data;
-	$self->{address} = unpack "\@$offset x a$asize", $$data;
-	$offset += 1 + $asize;
-	my $ssize = unpack "\@$offset C", $$data;
-	$self->{sa} = unpack "\@$offset x a$ssize", $$data;
+	( $self->{address}, $offset ) = decode Net::DNS::Text( $data, $offset );
+	( $self->{sa},	    $offset ) = decode Net::DNS::Text( $data, $offset );
 }
 
 
 sub encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	return '' unless $self->{address};
-	pack 'C a* C a*', map { ( length $_, $_ ) } @{$self}{qw(address sa)};
+	return '' unless defined $self->{address};
+	join '', $self->{address}->encode, $self->{sa}->encode;
 }
 
 
 sub format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless $self->{address};
-	join ' ', @{$self}{qw(address sa)};
+	my $address = $self->{address} || return '';
+	join ' ', $address->string, $self->{sa}->string;
 }
 
 
@@ -52,25 +51,33 @@ sub parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->address(shift);
-	$self->sa(shift);
+	$self->sa( shift || '' );
+}
+
+
+sub defaults() {			## specify RR attribute default values
+	my $self = shift;
+
+	$self->sa('');
 }
 
 
 sub address {
 	my $self = shift;
 
-	$self->{address} = shift if scalar @_;
-	$self->{address} || "";
+	$self->{address} = new Net::DNS::Text(shift) if scalar @_;
+	$self->{address}->value if defined wantarray && $self->{address};
 }
 
 
 sub sa {
 	my $self = shift;
 
-	$self->{sa} = shift if scalar @_;
-	$self->{sa} || "";
+	$self->{sa} = new Net::DNS::Text(shift) if scalar @_;
+	$self->{sa}->value if defined wantarray && $self->{sa};
 }
 
+
 1;
 __END__
 
@@ -117,12 +124,28 @@ Copyright (c)1997 Michael Fuhr.
 
 All rights reserved.
 
-This program is free software; you may redistribute it and/or
-modify it under the same terms as Perl itself.
-
 Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 
+=head1 LICENSE
+
+Permission to use, copy, modify, and distribute this software and its
+documentation for any purpose and without fee is hereby granted, provided
+that the above copyright notice appear in all copies and that both that
+copyright notice and this permission notice appear in supporting
+documentation, and that the name of the author not be used in advertising
+or publicity pertaining to distribution of the software without specific
+prior written permission.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+DEALINGS IN THE SOFTWARE.
+
+
 =head1 SEE ALSO
 
 L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC1183 Section 3.2
