@@ -1,10 +1,10 @@
 package Net::DNS::RR::RRSIG;
 
 #
-# $Id: RRSIG.pm 1339 2015-04-16 13:01:17Z willem $
+# $Id: RRSIG.pm 1352 2015-06-02 08:13:13Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1339 $)[1];
+$VERSION = (qw$LastChangedRevision: 1352 $)[1];
 
 
 use strict;
@@ -107,9 +107,16 @@ sub parse_rdata {			## populate RR from rdata in argument list
 
 	my %algbyval = reverse @algbyname;
 
-	my @algbynum = map { ( $_, 0 + $_ ) } ( 1 .. 250, keys %algbyval );
+	my $map = sub {
+		my $arg = shift;
+		unless ( $algbyval{$arg} ) {
+			$arg =~ s/[^A-Za-z0-9]//g;		# synthetic key
+			return uc $arg;
+		}
+		my @map = ( $arg, "$arg" => $arg );		# also accept number
+	};
 
-	my %algbyname = map { s/[^A-Za-z0-9]//g; $_ } @algbyname, @algbynum;
+	my %algbyname = map &$map($_), @algbyname;
 
 	sub algbyname {
 		my $name = shift;
