@@ -14,10 +14,10 @@ sub UNITCHECK {				## restore %SIG after compilation
 package Net::DNS::RR::SIG;
 
 #
-# $Id: SIG.pm 1339 2015-04-16 13:01:17Z willem $
+# $Id: SIG.pm 1352 2015-06-02 08:13:13Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1339 $)[1];
+$VERSION = (qw$LastChangedRevision: 1352 $)[1];
 
 
 use strict;
@@ -143,9 +143,16 @@ sub defaults() {			## specify RR attribute default values
 
 	my %algbyval = reverse @algbyname;
 
-	my @algbynum = map { ( $_, 0 + $_ ) } ( 1 .. 250, keys %algbyval );
+	my $map = sub {
+		my $arg = shift;
+		unless ( $algbyval{$arg} ) {
+			$arg =~ s/[^A-Za-z0-9]//g;		# synthetic key
+			return uc $arg;
+		}
+		my @map = ( $arg, "$arg" => $arg );		# also accept number
+	};
 
-	my %algbyname = map { s/[^A-Za-z0-9]//g; $_ } @algbyname, @algbynum;
+	my %algbyname = map &$map($_), @algbyname;
 
 	sub algbyname {
 		my $name = shift;
