@@ -1,10 +1,10 @@
 package Net::DNS::RR::SSHFP;
 
 #
-# $Id: SSHFP.pm 1326 2015-02-18 10:51:24Z willem $
+# $Id: SSHFP.pm 1337 2015-03-26 18:53:04Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1326 $)[1];
+$VERSION = (qw$LastChangedRevision: 1337 $)[1];
 
 
 use strict;
@@ -19,7 +19,7 @@ Net::DNS::RR::SSHFP - DNS SSHFP resource record
 
 use integer;
 
-use constant BABBLE => eval { require Digest::BubbleBabble; };
+use constant BABBLE => eval { require Digest::BubbleBabble; } || 0;
 
 
 sub decode_rdata {			## decode rdata from wire-format octet string
@@ -43,12 +43,9 @@ sub format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	return '' unless $self->{fpbin};
-	my $babble	= $self->babble;
-	my $fingerprint = $self->fp;
-	$fingerprint = "(\n$fingerprint )" if length $fingerprint > 40;
-	$fingerprint =~ s/(\S{64})/$1\n/g;
-	return join ' ', $self->algorithm, $self->fptype, $fingerprint unless $babble;
-	return join ' ', $self->algorithm, $self->fptype, $fingerprint, "\n;", $babble;
+	my @babble = BABBLE ? ( join '', ';', $self->babble, "\n" ) : ();
+	my @fprint = split /(\S{64})/, $self->fp;
+	my @rdata = $self->algorithm, $self->fptype, @fprint, @babble;
 }
 
 
@@ -98,7 +95,8 @@ sub babble {
 }
 
 
-sub fingerprint { &fp; }					# historical
+sub fingerprint { &fp; }		## historical
+
 
 1;
 __END__
@@ -180,12 +178,28 @@ Copyright (c)2007 Olaf Kolkman, NLnet Labs.
 
 All rights reserved.
 
-This program is free software; you may redistribute it and/or
-modify it under the same terms as Perl itself.
-
 Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 
+=head1 LICENSE
+
+Permission to use, copy, modify, and distribute this software and its
+documentation for any purpose and without fee is hereby granted, provided
+that the above copyright notice appear in all copies and that both that
+copyright notice and this permission notice appear in supporting
+documentation, and that the name of the author not be used in advertising
+or publicity pertaining to distribution of the software without specific
+prior written permission.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+DEALINGS IN THE SOFTWARE.
+
+
 =head1 SEE ALSO
 
 L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC4255
