@@ -1,10 +1,10 @@
 package Net::DNS::RR::TKEY;
 
 #
-# $Id: TKEY.pm 1326 2015-02-18 10:51:24Z willem $
+# $Id: TKEY.pm 1348 2015-05-27 09:55:13Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1326 $)[1];
+$VERSION = (qw$LastChangedRevision: 1348 $)[1];
 
 
 use strict;
@@ -144,7 +144,8 @@ sub other {
 }
 
 
-sub other_data {&other}			## historical
+sub other_data { &other; }		## historical
+
 
 1;
 __END__
@@ -232,12 +233,28 @@ Copyright (c)2000 Andrew Tridgell.
 
 All rights reserved.
 
-This program is free software; you may redistribute it and/or
-modify it under the same terms as Perl itself.
-
 Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 
+=head1 LICENSE
+
+Permission to use, copy, modify, and distribute this software and its
+documentation for any purpose and without fee is hereby granted, provided
+that the above copyright notice appear in all copies and that both that
+copyright notice and this permission notice appear in supporting
+documentation, and that the name of the author not be used in advertising
+or publicity pertaining to distribution of the software without specific
+prior written permission.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+DEALINGS IN THE SOFTWARE.
+
+
 =head1 SEE ALSO
 
 L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC2930
