@@ -1,10 +1,10 @@
 package Net::DNS::RR::TSIG;
 
 #
-# $Id: TSIG.pm 1348 2015-05-27 09:55:13Z willem $
+# $Id: TSIG.pm 1356 2015-06-11 08:44:12Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1348 $)[1];
+$VERSION = (qw$LastChangedRevision: 1356 $)[1];
 
 
 use strict;
@@ -51,9 +51,16 @@ use constant TSIG => typebyname qw(TSIG);
 
 	my %algbyval = reverse @algbyname;
 
-	my @algbynum = map { ( $_, 0 + $_ ) } keys %algbyval;	# accept algorithm number
+	my $map = sub {
+		my $arg = shift;
+		unless ( $algbyval{$arg} ) {
+			$arg =~ s/[^A-Za-z0-9]//g;		# synthetic key
+			return uc $arg;
+		}
+		my @map = ( $arg, "$arg" => $arg );		# also accept number
+	};
 
-	my %algbyname = map { s /[^A-Za-z0-9]//g; $_ } @algbyalias, @algbyname, @algbynum;
+	my %algbyname = map &$map($_), @algbyalias, @algbyname;
 
 
 	sub algbyname {
@@ -128,12 +135,13 @@ sub format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	my @lines = (
+		"\n",
+		map "; $_\n",
 		join( "\t", 'algorithm:', $self->algorithm ),
 		join( "\t", 'time signed:', $self->time_signed, 'fudge:', $self->fudge ),
 		join( "\t", 'signature:',   $self->mac ),
 		join( "\t", 'original id:', $self->original_id ),
 		join( "\t", $self->error, $self->other || '' ) );
-	join "\n; ", '', @lines;
 }
 
 
